@@ -1,3 +1,4 @@
+import sys
 import pytest
 import subprocess
 from pytest_cpp import error
@@ -246,18 +247,42 @@ def test_cpp_files_option(testdir, exes):
     exes.get('boost_success')
     exes.get('gtest')
 
-    result = testdir.inline_run('--collect-only')
-    reps = result.getreports()
-    assert len(reps) == 1
-    assert reps[0].result == []
+    result = testdir.runpytest('--collect-only')
+    result.stdout.fnmatch_lines('* no tests ran *')
 
     testdir.makeini('''
         [pytest]
         cpp_files = gtest* boost*
     ''')
-    result = testdir.inline_run('--collect-only')
-    assert len(result.matchreport(exes.exe_name('boost_success')).result) == 1
-    assert len(result.matchreport(exes.exe_name('gtest')).result) == 4
+    result = testdir.runpytest('--collect-only')
+    result.stdout.fnmatch_lines([
+        "*CppFile boost_success*",
+        "*CppFile gtest*",
+    ])
+
+
+# skip to avoid dealing with exes.get appending extension
+@pytest.mark.skipif(sys.platform.startswith('win'), reason='This is not a problem on Windows')
+def test_cpp_ignore_py_files(testdir, exes):
+    file_name = 'cpptest_success.py'
+    exes.get('gtest', 'cpptest_success.py')
+    testdir.makeini('''
+        [pytest]
+        cpp_files = cpptest_*
+    ''')
+
+    result = testdir.runpytest('--collect-only')
+    result.stdout.fnmatch_lines('* no tests ran *')
+
+    result = testdir.runpytest('--collect-only', '-o', 'cpp_ignore_py_files=False')
+    result.stdout.fnmatch_lines("*CppFile cpptest_success.py*")
+
+    # running directly skips out machinery as well.
+    result = testdir.runpytest('--collect-only', file_name)
+    result.stdout.fnmatch_lines('*1 error in*')
+
+    result = testdir.runpytest('--collect-only', '-o', 'cpp_ignore_py_files=False', file_name)
+    result.stdout.fnmatch_lines("*CppFile cpptest_success.py*")
 
 
 def test_google_one_argument(testdir, exes):
